@@ -128,10 +128,7 @@ class Utils(object):
 			try:
 				docker_client.images.get(image)
 			except Exception as de:
-				if sys.version_info < (3, 0):
-					raise DockerError('Failed to pull image: ' + str(e))
-				else:
-					raise DockerError('Failed to pull image: ' + str(e)) from e
+				raise DockerError('Failed to pull image: ' + str(e))
 
 		
 	@classmethod
